@@ -2,8 +2,9 @@ from collections.abc import Iterable
 from typing import Optional, Union
 
 from eda_report.document import ReportDocument
+from eda_report.multivariate import MultiVariable
 
-__version__ = "2.2.2"
+__version__ = "2.3.0"
 
 
 def get_word_report(
@@ -59,3 +60,24 @@ def get_word_report(
         target_variable=target_variable,
         table_style=table_style,
     )
+
+
+def summarize(data: Iterable) -> MultiVariable:
+    """Get a statistical summary of the supplied dataset.
+
+    Parameters
+    ----------
+    data : Iterable
+        The data to analyse.
+
+    Returns
+    -------
+    MultiVariable
+        Analysis results, with components as attributes.
+
+    Example
+    -------
+    .. literalinclude:: examples.txt
+       :lines: 85-113
+    """
+    return MultiVariable(data)
